@@ -8,10 +8,7 @@ test_that("oa2bibliometrix works", {
     to_publication_date = "2021-01-31"
   )
 
-  empty_au <- oa_fetch(entity="works", id="W3125831892")
-  w <- rbind(aria_citations, empty_au)
-
-  aria_bibli <- oa2bibliometrix(w)
+  expect_warning(aria_bibli <- oa2bibliometrix(aria_citations))
   expect_s3_class(aria_bibli, "data.frame")
-  expect_equal(nrow(w), nrow(aria_bibli))
+  expect_equal(nrow(aria_citations), nrow(aria_bibli))
 })
